@@ -31,7 +31,7 @@ struct stat * make_directory(CPInfo *, OPArg *, CPDD *);
 static VList * dir_traverse(VList *, CPInfo *, OPArg *, SDir *, CPDD *);
 static inline void delete_last_slash(const int, char []);
 static inline CPInfo * cpinfo_malloc(void);
-static inline char * get_to_plus_fromname(const char *, const char *);
+static inline char * get_dst_plus_srcname(const char *, const char *);
 static inline void count_link_plus(CPInfo *, CPDD *);
 static inline void count_file_plus(CPInfo *, CPDD *);
 static inline void count_dire_plus(CPInfo *, CPDD *);
@@ -52,7 +52,7 @@ static inline void set_same_or_different(const VList *, const char *, const char
 #define FILE_COPY \
 {\
 	count_file_plus(cpinfo, cpdd);\
-	set_same_or_different(drive_list, tmp_from, tmp_to, cpinfo, oparg); \
+	set_same_or_different(drive_list, tmp_src, tmp_dst, cpinfo, oparg); \
 	check_overwrite(oparg, sdir, cpinfo, cpdd);\
 	file_list = append_list(file_list, (void *)cpinfo);\
 }
@@ -60,38 +60,38 @@ static inline void set_same_or_different(const VList *, const char *, const char
 #define DIR_COPY \
 {\
 	_Bool cmp_flag = false;\
-	if(from_current_flag == true)\
+	if(src_current_flag == true)\
 	{\
-		char *from = cpinfo->from;\
-		char *to = cpinfo->to;\
-		int f_len = strlen(from);\
-		int t_len = strlen(to);\
+		char *s = cpinfo->src;\
+		char *d = cpinfo->dst;\
+		int s_len = strlen(s);\
+		int d_len = strlen(d);\
 \
-		if(f_len == t_len)\
+		if(s_len == d_len)\
 		{\
-			if(strcmp(from, to) == 0)\
+			if(strcmp(s, d) == 0)\
 			{\
 				cmp_flag = true;\
 			}\
 		}\
-		else if(f_len < t_len)\
+		else if(s_len < d_len)\
 		{\
 			for(;;)\
 			{\
-				if(*from == *to)\
+				if(*s == *d)\
 				{\
-					from++;\
-					to++;\
+					s++;\
+					d++;\
 				}\
 				else \
 				{\
 					break;\
 				}\
 \
-				if(*from == '\0')\
+				if(*s == '\0')\
 				{\
 \
-					if(*to == G_DIR_SEPARATOR)\
+					if(*d == G_DIR_SEPARATOR)\
 					{\
 						cmp_flag = true;\
 					}\
@@ -109,11 +109,11 @@ static inline void set_same_or_different(const VList *, const char *, const char
 \
 	if(cmp_flag == false)\
 	{\
-		set_same_or_different(drive_list, tmp_from, tmp_to, cpinfo, oparg); \
+		set_same_or_different(drive_list, tmp_src, tmp_dst, cpinfo, oparg); \
 \
 		struct stat *stat_buf;\
 \
-		if(from_current_flag == false)\
+		if(src_current_flag == false)\
 		{\
 			count_dire_plus(cpinfo, cpdd);\
 			stat_buf = make_directory(cpinfo, oparg, cpdd);\
@@ -121,15 +121,15 @@ static inline void set_same_or_different(const VList *, const char *, const char
 		}\
 		else \
 		{\
-			char *current_tmp = g_path_get_dirname(cpinfo->to);\
-			free(cpinfo->to);\
-			cpinfo->to = current_tmp;\
+			char *current_tmp = g_path_get_dirname(cpinfo->dst);\
+			free(cpinfo->dst);\
+			cpinfo->dst = current_tmp;\
 			/* cpinfoをリストに追加していないので、メモリリークしている。 */\
 		}\
 \
 		file_list = dir_traverse(file_list, cpinfo, oparg, sdir, cpdd);\
 \
-		if((from_current_flag == false) && (cpinfo->write == true))\
+		if((src_current_flag == false) && (cpinfo->write == true))\
 		{\
 			ch_time_and_mod_dir(cpinfo, stat_buf, cpdd);\
 		}\
@@ -166,21 +166,21 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 	cpdd->total_error = 0;
 	cpdd->thread_mode_count = 0;
 
-	char tmp_from[PATH_MAX];
-	char tmp_to[PATH_MAX];
-	int loop = oparg->fromindex;
-	int loop_to = oparg->toindex;
+	char tmp_src[PATH_MAX];
+	char tmp_dst[PATH_MAX];
+	int loop = oparg->src_index;
+	int loop_dst = oparg->dst_index;
 
 	_Bool file_found = false;
 
-	if(g_file_test(oparg->argv[loop_to], G_FILE_TEST_IS_SYMLINK) == TRUE)
+	if(g_file_test(oparg->argv[loop_dst], G_FILE_TEST_IS_SYMLINK) == TRUE)
 	{
 		fprintf(stderr, "コピー先がシンボリックリンクです\n");
 		exit(EXIT_FAILURE);
 	}
 
 	/* 三項演算子 */
-	((loop_to - loop) == 1) ? (acount = SINGULAR) : (acount = PLURAL);
+	((loop_dst - loop) == 1) ? (acount = SINGULAR) : (acount = PLURAL);
 
 	/* コピー元が.でコピー先が存在しないとき用の処理 */
 	switch(acount)
@@ -199,7 +199,7 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 			{
 				errno = 0;
 
-				if(mkdir(oparg->argv[loop_to], 0755) == -1)
+				if(mkdir(oparg->argv[loop_dst], 0755) == -1)
 				{
 					if((errno != EEXIST) && (errno != 0))
 					{
@@ -214,7 +214,7 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 	}
 
 	errno = 0;
-	realpath(oparg->argv[loop_to], tmp_to);
+	realpath(oparg->argv[loop_dst], tmp_dst);
 
 	if(errno == 0)
 	{
@@ -222,10 +222,10 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 	}
 	else if(errno == ENOENT)
 	{
-		char *c = g_path_get_dirname(oparg->argv[loop_to]);
+		char *c = g_path_get_dirname(oparg->argv[loop_dst]);
 
 		errno = 0;
-		realpath(c, tmp_to);
+		realpath(c, tmp_dst);
 
 		if(errno != 0)
 		{
@@ -243,12 +243,12 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 		exit(EXIT_FAILURE);
 	}
 
-	int len_to = strlen(tmp_to);
-	delete_last_slash(len_to, tmp_to);
+	int len_dst = strlen(tmp_dst);
+	delete_last_slash(len_dst, tmp_dst);
 
-	for(; loop < loop_to; loop++)
+	for(; loop < loop_dst; loop++)
 	{
-		_Bool from_current_flag = false;
+		_Bool src_current_flag = false;
 
 		/* strcmpは等しければ0を返す */
 		if(strcmp(oparg->argv[loop], "..") == 0)
@@ -258,7 +258,7 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 		}
 		else if(strcmp(oparg->argv[loop], ".") == 0)
 		{
-			from_current_flag = true;
+			src_current_flag = true;
 		}
 		/*
 		 * メモ
@@ -271,12 +271,12 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 		if(g_file_test(oparg->argv[loop], G_FILE_TEST_IS_SYMLINK) == TRUE)
 		{
 			link_flag = true;
-			strcpy(tmp_from, oparg->argv[loop]);
+			strcpy(tmp_src, oparg->argv[loop]);
 		}
 		else
 		{
 			errno = 0;
-			realpath(oparg->argv[loop], tmp_from);
+			realpath(oparg->argv[loop], tmp_src);
 
 			if(errno != 0)
 			{
@@ -286,40 +286,40 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 			}
 		}
 
-		int len_from = strlen(tmp_from);
-		delete_last_slash(len_from, tmp_from);
+		int len_src = strlen(tmp_src);
+		delete_last_slash(len_src, tmp_src);
 
 		CPInfo *cpinfo = cpinfo_malloc();
 
-		len_from++;
-		cpinfo->from = xmalloc(len_from);
-		memcpy(cpinfo->from, tmp_from, len_from);
-		len_from--;
+		len_src++;
+		cpinfo->src = xmalloc(len_src);
+		memcpy(cpinfo->src, tmp_src, len_src);
+		len_src--;
 
 		if(file_found == true)
 		{
-			if(g_file_test(tmp_to, G_FILE_TEST_IS_REGULAR) == TRUE)
+			if(g_file_test(tmp_dst, G_FILE_TEST_IS_REGULAR) == TRUE)
 			{
-				len_to++;
-				cpinfo->to = xmalloc(len_to);
-				memcpy(cpinfo->to, tmp_to, len_to);
-				len_to--;
+				len_dst++;
+				cpinfo->dst = xmalloc(len_dst);
+				memcpy(cpinfo->dst, tmp_dst, len_dst);
+				len_dst--;
 
 				switch(acount)
 				{
 				case SINGULAR:
 					if(link_flag == true)
 					{
-						fprintf(stderr, "リンク (%s) に対するコピー先が不正 (ファイル) です\n", tmp_from);
+						fprintf(stderr, "リンク (%s) に対するコピー先が不正 (ファイル) です\n", tmp_src);
 						exit(EXIT_FAILURE);
 					}
-					else if(g_file_test(tmp_from, G_FILE_TEST_IS_REGULAR) == TRUE)
+					else if(g_file_test(tmp_src, G_FILE_TEST_IS_REGULAR) == TRUE)
 					{
 						FILE_COPY
 					}
-					else if(g_file_test(tmp_from, G_FILE_TEST_IS_DIR) == TRUE)
+					else if(g_file_test(tmp_src, G_FILE_TEST_IS_DIR) == TRUE)
 					{
-						fprintf(stderr, "フォルダ (%s) に対するコピー先が不正 (ファイル) です\n", tmp_from);
+						fprintf(stderr, "フォルダ (%s) に対するコピー先が不正 (ファイル) です\n", tmp_src);
 						exit(EXIT_FAILURE);
 					}
 					else
@@ -335,24 +335,24 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 					break;
 				}
 			}
-			else if(g_file_test(tmp_to, G_FILE_TEST_IS_DIR) == TRUE)
+			else if(g_file_test(tmp_dst, G_FILE_TEST_IS_DIR) == TRUE)
 			{
-				cpinfo->to = get_to_plus_fromname(tmp_from, tmp_to);
+				cpinfo->dst = get_dst_plus_srcname(tmp_src, tmp_dst);
 				if(link_flag == true)
 				{
 					LINK_COPY
 				}
-				else if(g_file_test(tmp_from, G_FILE_TEST_IS_REGULAR) == TRUE)
+				else if(g_file_test(tmp_src, G_FILE_TEST_IS_REGULAR) == TRUE)
 				{
 					FILE_COPY
 				}
-				else if(g_file_test(tmp_from, G_FILE_TEST_IS_DIR) == TRUE)
+				else if(g_file_test(tmp_src, G_FILE_TEST_IS_DIR) == TRUE)
 				{
 					DIR_COPY
 				}
 				else
 				{
-					fprintf(stderr, "%s をスキップします\n", tmp_from);
+					fprintf(stderr, "%s をスキップします\n", tmp_src);
 				}
 			}
 			else
@@ -368,7 +368,7 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 				char *target;
 				errno = 0;
 
-				if(mkdir(oparg->argv[loop_to], 0755) == -1)
+				if(mkdir(oparg->argv[loop_dst], 0755) == -1)
 				{
 					if((errno != EEXIST) && (errno != 0))
 					{
@@ -379,33 +379,33 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 				}
 				else
 				{
-					target = get_to_plus_fromname(oparg->argv[loop_to], tmp_to);
-					strcpy(tmp_to, target);
-					cpinfo->to = get_to_plus_fromname(tmp_from, target);
+					target = get_dst_plus_srcname(oparg->argv[loop_dst], tmp_dst);
+					strcpy(tmp_dst, target);
+					cpinfo->dst = get_dst_plus_srcname(tmp_src, target);
 					free(target);
 					file_found = true;
 				}
 			}
 			else
 			{
-				cpinfo->to = get_to_plus_fromname(oparg->argv[loop_to], tmp_to);
+				cpinfo->dst = get_dst_plus_srcname(oparg->argv[loop_dst], tmp_dst);
 			}
 
 			if(link_flag == true)
 			{
 				LINK_COPY
 			}
-			else if(g_file_test(tmp_from, G_FILE_TEST_IS_REGULAR) == TRUE)
+			else if(g_file_test(tmp_src, G_FILE_TEST_IS_REGULAR) == TRUE)
 			{
 				FILE_COPY
 			}
-			else if(g_file_test(tmp_from, G_FILE_TEST_IS_DIR) == TRUE)
+			else if(g_file_test(tmp_src, G_FILE_TEST_IS_DIR) == TRUE)
 			{
 				DIR_COPY
 			}
 			else
 			{
-				fprintf(stderr, "%s をスキップします\n", tmp_from);
+				fprintf(stderr, "%s をスキップします\n", tmp_src);
 			}
 		}
 	}
@@ -430,7 +430,7 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 
 #define FILE_WRITE_OR_CREATE_LINK_OVERWRITE \
 {\
-	if(cpinfo->from_type == REGULAR)\
+	if(cpinfo->src_type == REGULAR)\
 	{\
 		read_write(oparg, sdir, cpinfo, cpdd);\
 	}\
@@ -441,11 +441,11 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 }
 
 #define MAKE_THIS_DIR \
-this_dir = g_path_get_dirname(cpinfo->to);
+this_dir = g_path_get_dirname(cpinfo->dst);
 
 #define THIS_DIR_CHECK \
 {\
-	char *tmp = g_path_get_dirname(cpinfo->to);\
+	char *tmp = g_path_get_dirname(cpinfo->dst);\
 	char *tmp2 = this_dir;\
 	char *tmp_free = tmp;\
 	int tmp_len = strlen(tmp);\
@@ -529,13 +529,13 @@ void check_overwrite(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 		info_flag = true;
 	}
 
-	gboolean fcheck  = g_file_test(cpinfo->to, G_FILE_TEST_EXISTS);
+	gboolean fcheck  = g_file_test(cpinfo->dst, G_FILE_TEST_EXISTS);
 
 	/* TRUE・FALSE　→　glib */
 	/* true・false　→　stdbool */
 	if(fcheck == FALSE)
 	{
-		if(cpinfo->from_type == REGULAR)
+		if(cpinfo->src_type == REGULAR)
 		{
 			read_write(oparg, sdir, cpinfo, cpdd);
 		}
@@ -565,7 +565,7 @@ INPUT:
 			switch(iowt)
 			{
 			case INFO:
-				printf("%sは既に存在します。\n", cpinfo->to);
+				printf("%sは既に存在します。\n", cpinfo->dst);
 				puts("上書きしますか? (y: Yes  a: 全てYes  d: このフォルダのみYes  n: No  o: このフォルダのみNo  z: 全てNo)");
 				printf(" : ");
 
@@ -689,26 +689,26 @@ INPUT:
 struct stat * make_directory(CPInfo *cpinfo, OPArg *oparg, CPDD *cpdd)
 {
 	errno = 0;
-	if(g_file_test(cpinfo->to, G_FILE_TEST_EXISTS) == TRUE)
+	if(g_file_test(cpinfo->dst, G_FILE_TEST_EXISTS) == TRUE)
 	{
 		/* フォルダの作成は行わない */
 		DO_NOT_OVERWRITE_FLAG
 	}
-	else if(mkdir(cpinfo->to, 0755) == -1)
+	else if(mkdir(cpinfo->dst, 0755) == -1)
 	{
 		cpinfo->write = false;
 
 		if((errno != EEXIST) && (errno != 0))
 		{
 			print_error("mkdir", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, "フォルダの作成に失敗しました (%s) \n", cpinfo->to);
+			fprintf(stderr, "フォルダの作成に失敗しました (%s) \n", cpinfo->dst);
 		}
 	}
 	else
 	{
 		if(oparg->V == VERBOS)
 		{
-			printf("%s -> %s\n", cpinfo->from, cpinfo->to);
+			printf("%s -> %s\n", cpinfo->src, cpinfo->dst);
 			fflush(stdout);
 		}
 
@@ -718,10 +718,10 @@ struct stat * make_directory(CPInfo *cpinfo, OPArg *oparg, CPDD *cpdd)
 
 	struct stat *stat_buf = xmalloc(sizeof(struct stat));
 
-	if(stat(cpinfo->from, stat_buf) != 0)
+	if(stat(cpinfo->src, stat_buf) != 0)
 	{
 		print_error("stat", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "フォルダ情報取得エラーです (%s) \n", cpinfo->from);
+		fprintf(stderr, "フォルダ情報取得エラーです (%s) \n", cpinfo->src);
 		free(stat_buf);
 		stat_buf = NULL;
 	}
@@ -767,10 +767,10 @@ static VList * dir_traverse(VList *file_list, CPInfo *cpinfo_tmp, OPArg *oparg,
 	DIR *dp = NULL;
 	struct dirent *entry = NULL;
 	const char *d_name;
-	const char *from_dir = cpinfo_tmp->from;
-	const char *to_dir = cpinfo_tmp->to;
+	const char *src_dir = cpinfo_tmp->src;
+	const char *dst_dir = cpinfo_tmp->dst;
 
-	if((dp = opendir(from_dir)) != NULL)
+	if((dp = opendir(src_dir)) != NULL)
 	{
 		while((entry = readdir(dp)) != NULL)
 		{
@@ -778,23 +778,23 @@ static VList * dir_traverse(VList *file_list, CPInfo *cpinfo_tmp, OPArg *oparg,
 			/* strcmpは等しければ0を返す（0は偽） */
 			if(strcmp(d_name, ".") && strcmp(d_name, ".."))
 			{
-				int fdir = strlen(from_dir);
-				int tdir = strlen(to_dir);
+				int fdir = strlen(src_dir);
+				int tdir = strlen(dst_dir);
 				int d_len = strlen(d_name);
 
 				CPInfo *cpinfo = cpinfo_malloc();
 
 				/* +2は、 \0 と / の分 */
-				cpinfo->from = xmalloc(fdir + d_len + 2);
-				cpinfo->to = xmalloc(tdir + d_len + 2);
-				cpinfo->tofs = cpinfo_tmp->tofs;
+				cpinfo->src = xmalloc(fdir + d_len + 2);
+				cpinfo->dst = xmalloc(tdir + d_len + 2);
+				cpinfo->dstfs = cpinfo_tmp->dstfs;
 				cpinfo->copy_mode = cpinfo_tmp->copy_mode;
 				/*
 				 * sprintfは便利だってLeptonさんが言ってた。
 				 * printf系の関数は遅い？知るか。
 				*/
-				sprintf(cpinfo->from, "%s%s%s", from_dir, G_DIR_SEPARATOR_S, d_name);
-				sprintf(cpinfo->to, "%s%s%s", to_dir, G_DIR_SEPARATOR_S, d_name);
+				sprintf(cpinfo->src, "%s%s%s", src_dir, G_DIR_SEPARATOR_S, d_name);
+				sprintf(cpinfo->dst, "%s%s%s", dst_dir, G_DIR_SEPARATOR_S, d_name);
 
 				switch(entry->d_type)
 				{
@@ -811,21 +811,21 @@ static VList * dir_traverse(VList *file_list, CPInfo *cpinfo_tmp, OPArg *oparg,
 					break;
 
 				default:
-					if(g_file_test(cpinfo->from, G_FILE_TEST_IS_SYMLINK) == TRUE)
+					if(g_file_test(cpinfo->src, G_FILE_TEST_IS_SYMLINK) == TRUE)
 					{
 						TYPE_IS_LINK
 					}
-					else if(g_file_test(cpinfo->from, G_FILE_TEST_IS_REGULAR) == TRUE)
+					else if(g_file_test(cpinfo->src, G_FILE_TEST_IS_REGULAR) == TRUE)
 					{
 						TYPE_IS_FILE
 					}
-					else if(g_file_test(cpinfo->from, G_FILE_TEST_IS_DIR) == TRUE)
+					else if(g_file_test(cpinfo->src, G_FILE_TEST_IS_DIR) == TRUE)
 					{
 						TYPE_IS_DIR
 					}
 					else
 					{
-						fprintf(stderr, "このファイル (%s) をスキップします\n", cpinfo->from);
+						fprintf(stderr, "このファイル (%s) をスキップします\n", cpinfo->src);
 					}
 					break;
 				}
@@ -839,7 +839,7 @@ static VList * dir_traverse(VList *file_list, CPInfo *cpinfo_tmp, OPArg *oparg,
 	else
 	{
 		print_error("opendir", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "%s を読み取れませんでした\n", from_dir);
+		fprintf(stderr, "%s を読み取れませんでした\n", src_dir);
 	}
 
 	return file_list;
@@ -861,18 +861,18 @@ static inline void delete_last_slash(const int len, char tmp[])
 static inline CPInfo * cpinfo_malloc(void)
 {
 	CPInfo *cpinfo = xmalloc(sizeof(CPInfo));
-	cpinfo->from = NULL;
-	cpinfo->to = NULL;
-	cpinfo->tofs = NULL;
-/*	cpinfo->from_type = */
+	cpinfo->src = NULL;
+	cpinfo->dst = NULL;
+	cpinfo->dstfs = NULL;
+/*	cpinfo->src_type = */
 	cpinfo->copy_mode = SAME;
 	cpinfo->write = false;
 	cpinfo->skip = false;
 	cpinfo->hash_check = false;
 	cpinfo->file_test = false;
 	cpinfo->verify_md5 = NULL;
-	cpinfo->from_size = 0;
-	cpinfo->to_size = 0;
+	cpinfo->src_size = 0;
+	cpinfo->dst_size = 0;
 
 	return cpinfo;
 }
@@ -881,15 +881,15 @@ static inline CPInfo * cpinfo_malloc(void)
  * コピー元ファイル名とコピー先パスを連結する。
  * g_path_get_basename と g_build_path を同時にやる感じ。
 *******************************************************************************/
-static inline char * get_to_plus_fromname(const char *from, const char *to)
+static inline char * get_dst_plus_srcname(const char *src, const char *dst)
 {
-	char fname[PATH_MAX];
+	char sname[PATH_MAX];
 	char *return_name;
-	int from_len = strlen(from);
-	int to_len = strlen(to);
+	int src_len = strlen(src);
+	int dst_len = strlen(dst);
 	_Bool flag = false;
 
-	for(int i = from_len - 1; i >= 0; i--)
+	for(int i = src_len - 1; i >= 0; i--)
 	{
 		/*
 		 * 最後のパス区切り文字からコピーするので、
@@ -897,16 +897,16 @@ static inline char * get_to_plus_fromname(const char *from, const char *to)
 		 * 
 		 * /ファイル名\0
 		*/
-		if(from[i] == G_DIR_SEPARATOR)
+		if(src[i] == G_DIR_SEPARATOR)
 		{
 			flag = true;
 			int j = 0;
 
 			for(;;)
 			{
-				fname[j] = from[i];
+				sname[j] = src[i];
 
-				if(from[i] == '\0')
+				if(src[i] == '\0')
 				{
 					goto BASENAME_END;
 				}
@@ -921,11 +921,11 @@ BASENAME_END:
 
 	if(flag == true)
 	{
-		int name_len = strlen(fname);
+		int name_len = strlen(sname);
 		/* +1 はヌル文字（\0）の分 */
-		return_name = xmalloc(to_len + name_len + 1);
-		memcpy(return_name, to, to_len + 1);
-		strcat(return_name, fname);
+		return_name = xmalloc(dst_len + name_len + 1);
+		memcpy(return_name, dst, dst_len + 1);
+		strcat(return_name, sname);
 	}
 	else
 	{
@@ -934,14 +934,14 @@ BASENAME_END:
 		 * メモリ破壊のバグぅうわあああ。
 		 * append_list内のxmalloc内で、malloc(): memory corruption
 		 * とか出てアボートするバグを直せた。
-		 * return_name = xmalloc(from_len + to_len + 1);
+		 * return_name = xmalloc(src_len + dst_len + 1);
 		 * ↑こいつが原因だった。G_DIR_SEPARATOR_Sのことを忘れてた。
 		 * 多分これで大丈夫。
 		*/
-		return_name = xmalloc(from_len + to_len + (sizeof(G_DIR_SEPARATOR_S) + 1));
-		memcpy(return_name, to, to_len + 1);
+		return_name = xmalloc(src_len + dst_len + (sizeof(G_DIR_SEPARATOR_S) + 1));
+		memcpy(return_name, dst, dst_len + 1);
 		strcat(return_name, G_DIR_SEPARATOR_S);
-		strcat(return_name, from);
+		strcat(return_name, src);
 	}
 
 	return return_name;
@@ -951,7 +951,7 @@ BASENAME_END:
 *******************************************************************************/
 static inline void count_link_plus(CPInfo *cpinfo, CPDD *cpdd)
 {
-	cpinfo->from_type = SYMBOLICLINK;
+	cpinfo->src_type = SYMBOLICLINK;
 	cpdd->link_count++;
 }
 
@@ -959,7 +959,7 @@ static inline void count_link_plus(CPInfo *cpinfo, CPDD *cpdd)
 *******************************************************************************/
 static inline void count_file_plus(CPInfo *cpinfo, CPDD *cpdd)
 {
-	cpinfo->from_type = REGULAR;
+	cpinfo->src_type = REGULAR;
 	cpdd->file_count++;
 }
 
@@ -967,7 +967,7 @@ static inline void count_file_plus(CPInfo *cpinfo, CPDD *cpdd)
 *******************************************************************************/
 static inline void count_dire_plus(CPInfo *cpinfo, CPDD *cpdd)
 {
-	cpinfo->from_type = DIRECTORY;
+	cpinfo->src_type = DIRECTORY;
 	cpdd->dir_count++;
 }
 
@@ -977,30 +977,30 @@ static inline void ch_time_and_mod_dir(const CPInfo *cpinfo, const struct stat *
 {
 	errno = 0;
 
-	if(chmod(cpinfo->to, stat_buf->st_mode) == -1)
+	if(chmod(cpinfo->dst, stat_buf->st_mode) == -1)
 	{
 		print_error("chmod", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "フォルダ情報変更エラーです (%s) \n", cpinfo->to);
+		fprintf(stderr, "フォルダ情報変更エラーです (%s) \n", cpinfo->dst);
 	}
 
 /*
-	if(chown(cpinfo->to, stat_buf->st_uid, stat_buf->st_gid) == -1)
+	if(chown(cpinfo->dst, stat_buf->st_uid, stat_buf->st_gid) == -1)
 	{
 		print_error("chown", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "フォルダ情報変更エラーです (%s) \n", cpinfo->to);
+		fprintf(stderr, "フォルダ情報変更エラーです (%s) \n", cpinfo->dst);
 	}
 */
 
-	chown(cpinfo->to, stat_buf->st_uid, stat_buf->st_gid);
+	chown(cpinfo->dst, stat_buf->st_uid, stat_buf->st_gid);
 
 	static struct utimbuf times;
 	times.actime  = stat_buf->st_atime;
 	times.modtime = stat_buf->st_mtime;
 
-	if(utime(cpinfo->to, &times) == -1)
+	if(utime(cpinfo->dst, &times) == -1)
 	{
 		print_error("utime", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "フォルダ情報変更エラーです (%s) \n", cpinfo->to);
+		fprintf(stderr, "フォルダ情報変更エラーです (%s) \n", cpinfo->dst);
 	}
 }
 
@@ -1066,15 +1066,15 @@ for(;;)\
 /******************************************************************************
  * ドライブが同一かどうか調べる
 *******************************************************************************/
-static inline void set_same_or_different(const VList *drive_list, const char *from, const char *to, CPInfo *cpinfo, OPArg *oparg)
+static inline void set_same_or_different(const VList *drive_list, const char *src, const char *dst, CPInfo *cpinfo, OPArg *oparg)
 {
 	/*
 	 * キャストしないと警告が出る
 	 * warning: initialization discards qualifiers from pointer target type
 	*/
 	VList *tmplist = (VList *)drive_list;
-	char *fromdev = NULL;
-	char *todev = NULL;
+	char *srcdev = NULL;
+	char *dstdev = NULL;
 
 	for(;;)
 	{
@@ -1084,40 +1084,40 @@ printf("%s %s\n", tmp->device, tmp->mount_point);
 */
 		if((tmp->mount_point[1] == '\0') && (tmp->mount_point[0] == G_DIR_SEPARATOR))
 		{
-			if(fromdev == NULL)
+			if(srcdev == NULL)
 			{
-				fromdev = tmp->device;
+				srcdev = tmp->device;
 			}
 
-			if(todev == NULL)
+			if(dstdev == NULL)
 			{
-				todev = tmp->device;
-				cpinfo->tofs = tmp->fs;
+				dstdev = tmp->device;
+				cpinfo->dstfs = tmp->fs;
 			}
 
 			goto DEV_CHECK_SKIP;
 		}
 
 		{
-			const char *path = from;
+			const char *path = src;
 
 			PATH_CHECK
 
 			if(flag == true)
 			{
-				fromdev = tmp->device;
+				srcdev = tmp->device;
 			}
 		}
 
 		{
-			const char *path = to;
+			const char *path = dst;
 
 			PATH_CHECK
 
 			if(flag == true)
 			{
-				todev = tmp->device;
-				cpinfo->tofs = tmp->fs;
+				dstdev = tmp->device;
+				cpinfo->dstfs = tmp->fs;
 			}
 		}
 
@@ -1133,9 +1133,9 @@ DEV_CHECK_SKIP:
 		}
 	}
 
-	if((fromdev != NULL) && (todev != NULL))
+	if((srcdev != NULL) && (dstdev != NULL))
 	{
-		if(strcmp(fromdev, todev) == 0)
+		if(strcmp(srcdev, dstdev) == 0)
 		{
 			cpinfo->copy_mode = SAME;
 		}
@@ -1151,14 +1151,18 @@ DEV_CHECK_SKIP:
 
 	switch(oparg->THREAD_MODE)
 	{
+/*
 	case DRIVE_SAME:
 		cpinfo->copy_mode = SAME;
 		break;
+*/
 	case DRIVE_DIFFERENT:
 		cpinfo->copy_mode = DIFFERENT;
 		break;
+
 	case DRIVE_AUTO:
 		break;
+
 	default:
 		cpinfo->copy_mode = SAME;
 		break;
