@@ -1,6 +1,6 @@
 #include <stdio.h>
 
-static char version[] = "0.13.1 beta";
+static char version[] = "0.13.2 beta";
 
 /* 関数プロトタイプ */
 void help(void);
@@ -11,34 +11,34 @@ void help(void);
 void help()
 {
 	printf("バージョン %s\n", version);
-	puts("使用方法 : snowcp [option] source dest");
-	puts("sourceからdestへコピーする。optionとsourceは複数可。destが存在しない場合は自動的に作成する。");
+	puts("使用方法 : snowcp [option] src dst");
+	puts("srcからdstへコピーする。optionとsrcは複数可。dstが存在しない場合は自動的に作成する。");
 	puts("");
 	puts("オプション");
 	puts(" -1 MODE    SHA-1でコンペアを行う。");
 	puts("            MODEが1の場合はコピー直後に、");
 	puts("            2の場合は全コピー終了後に比較する。");
-	puts("            一致しなかった場合はdestを削除する。");
-	puts("            (例 : snowcp -1 1 source dest)");
+	puts("            一致しなかった場合はdstを削除する。");
+	puts("            (例 : snowcp -1 1 src dst)");
 	puts("");
 	puts(" -5 MODE    MD5でコンペアを行う。");
 	puts("            MODEが1の場合はコピー直後に、");
 	puts("            2の場合は全コピー終了後に比較する。");
-	puts("            一致しなかった場合はdestを削除する。");
-	puts("            (例 : snowcp -5 1 source dest)");
+	puts("            一致しなかった場合はdstを削除する。");
+	puts("            (例 : snowcp -5 1 src dst)");
 	puts("");
 	puts(" -0         ベリファイ・コンペアを行わない。");
 	puts("            (-1、-5、-c、-rオプションを無効にする。)");
 	puts("");
 	puts(" -b NUMBER  バッファの量を指定する（MB単位、デフォルト値は32）。");
-	puts("            (例 : snowcp -b 64 source dest)");
+	puts("            (例 : snowcp -b 64 src dst)");
 	puts("");
 /*
 	puts(" -c MODE    memcmpで比較する。");
 	puts("            MODEが1の場合はコピー直後に、");
 	puts("            2の場合は全コピー終了後に比較する。");
-	puts("            一致しなかった場合はdestを削除する。");
-	puts("            (例 : snowcp -c 1 source dest)");
+	puts("            一致しなかった場合はdstを削除する。");
+	puts("            (例 : snowcp -c 1 src dst)");
 	puts("");
 */
 	puts(" -h         ヘルプを表示する。");
@@ -48,23 +48,23 @@ void help()
 	puts("            (例 : snowcp --help)");
 	puts("");
 	puts(" -i         ファイルを上書きする前に確認する。");
-	puts("            (例 : snowcp -i source dest)");
+	puts("            (例 : snowcp -i src dst)");
 	puts("");
 	puts(" -I         -iオプションを無効にする。");
-	puts("            (例 : snowcp -I source dest)");
+	puts("            (例 : snowcp -I src dst)");
 	puts("");
 	puts(" -l         ベリファイ・コンペアのログを保存する。");
 	puts("            -cオプションのログは保存しない。");
-	puts("            (例 : snowcp -1 2 -l source dest)");
+	puts("            (例 : snowcp -1 2 -l src dst)");
 	puts("");
 	puts(" -L         -lオプションを無効にする。");
-	puts("            (例 : snowcp -L source dest)");
+	puts("            (例 : snowcp -L src dst)");
 	puts("");
 	puts(" -m         コピー終了後、コピー元を削除する。");
-	puts("            (例 : snowcp -m source dest)");
+	puts("            (例 : snowcp -m src dst)");
 	puts("");
 	puts(" -M         -mオプションを無効にする。");
-	puts("            (例 : snowcp -M source dest)");
+	puts("            (例 : snowcp -M src dst)");
 	puts("");
 	puts(" -o         設定を保存する。");
 	puts("            (例 : snowcp -o)");
@@ -72,24 +72,24 @@ void help()
 	puts(" -r MODE    ベリファイを行う。");
 	puts("            MODEが1の場合はコピー直後に、");
 	puts("            2の場合は全コピー終了後にベリファイを実行する。");
-	puts("            一致しなかった場合はdestを削除する。");
-	puts("            (例 : snowcp -r 1 source dest)");
+	puts("            一致しなかった場合はdstを削除する。");
+	puts("            (例 : snowcp -r 1 src dst)");
 	puts("");
 	puts(" -t MODE    スレッドモードを指定する。");
 	puts("            MODEが1の場合は常に同一ドライブモード、");
 	puts("            2の場合は常に別ドライブモード、");
 	puts("            0の場合は自動判別モードで動作する。");
-	puts("            (例 : snowcp -t 1 source dest)");
+	puts("            (例 : snowcp -t 1 src dst)");
 	puts("");
 	puts(" -v         コピー中のファイル名を表示する。");
-	puts("            (例 : snowcp -v source dest)");
+	puts("            (例 : snowcp -v src dst)");
 	puts("");
 	puts(" -w MODE    上書きモードを指定する。");
 	puts("            MODEが1の場合はサイズか日付が異なる時、");
 	puts("            2の場合は日付が新しい時、");
 	puts("            3の場合は常に上書きする。");
 	puts("            0の場合、上書きしない。");
-	puts("            (例 : snowcp -w 3 source dest)");
+	puts("            (例 : snowcp -w 3 src dst)");
 	puts("");
 	puts("注 : オプションは後に入力した方が優先される。例えば snowcp -iw とした場合、-wオプションが有効になる。");
 	puts("");
