@@ -4,7 +4,7 @@
 */
 #define _GNU_SOURCE
 
-#define USE_O_DIRECT_SIZE 1024 * 1024 * 200
+#define USE_O_DIRECT_SIZE 1024 * 1024 * 1
 
 #include "ch_time_and_mod.h" // inline
 #include "compare_hash.h"
@@ -29,43 +29,43 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
-#define TO_OPEN \
+#define OPEN_CHECK_DST \
 {\
 	errno = 0;\
-	if(o_direct_write_flag == false)\
+	if((o_direct_write_flag == false) || (src_size_local < USE_O_DIRECT_SIZE))\
 	{\
-		ito = open(cpinfo->to, O_CREAT | O_WRONLY | O_TRUNC | O_NOFOLLOW, S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH);\
-		o_direct_write_open = false;\
+		idst = open(cpinfo->dst, O_CREAT | O_WRONLY | O_TRUNC | O_NOFOLLOW, S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH);\
+		o_direct_open_dst = false;\
 	}\
 	else \
 	{\
-		ito = open(cpinfo->to, O_CREAT | O_WRONLY | O_TRUNC | O_NOFOLLOW | O_DIRECT, S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH);\
-		o_direct_write_open = true;\
+		idst = open(cpinfo->dst, O_CREAT | O_WRONLY | O_TRUNC | O_NOFOLLOW | O_DIRECT, S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH);\
+		o_direct_open_dst = true;\
 	}\
 \
-	if(ito == -1)\
+	if(idst == -1)\
 	{\
-		o_direct_write_open = false;\
+		o_direct_open_dst = false;\
 		print_error("open", __FILE__, __LINE__, cpdd);\
 	}\
 	else \
 	{\
-		to_open = true;\
+		open_dst = true;\
 		cpdd->mk_file_count++;\
 	}\
 }
 
 #define HASH_CHECK \
 {\
-	if((from_open == true) && (to_open == true))\
+	if((open_src == true) && (open_dst == true))\
 	{\
 		compare_hash(oparg, sdir, cpinfo, cpdd);\
 	}\
 	else if(cpinfo->skip == false)\
 	{\
 		fprintf(stderr, "ファイルのオープンに失敗しているため、コンペアをスキップします\n");\
-		fprintf(stderr, "from : %s\n", cpinfo->from);\
-		fprintf(stderr, "to   : %s\n", cpinfo->to);\
+		fprintf(stderr, "src : %s\n", cpinfo->src);\
+		fprintf(stderr, "dst : %s\n", cpinfo->dst);\
 	}\
 }
 
@@ -90,27 +90,22 @@ struct verify_data
 };
 
 static void *buf[2];
-static off_t from_size_local;
+static off_t src_size_local;
 static off_t written_size[2];
 static off_t next_write_size[2];
 static off_t total_read_local;
 static off_t total_write_local;
 static off_t total_read_error; // スレッド用
 static off_t total_write_error; // スレッド用
-static int ifrom;
-static int ito;
+static int isrc;
+static int idst;
 static int buffer_size;
 static int buffer_size_half;
 static int buffer_size_thread;
-static int ri;
-static int wi;
+static int ri; // index number
+static int wi; // index number
 static long psize;
-static _Bool from_open;
-static _Bool from_stat;
-static _Bool to_open;
 static _Bool verify;
-static _Bool o_direct_write_flag;
-static _Bool o_direct_write_open;
 
 /* ※注意。グローバル変数。 */
 char *write_now;
@@ -130,15 +125,22 @@ static void * do_md5_append(void *tmp);
 *******************************************************************************/
 void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd)
 {
-	static struct stat stat_buf;
 	static _Bool filesystem_check = false;
 	static _Bool fallocate_support = false;
+	static _Bool o_direct_write_flag = false;
 	static _Bool verify_option_check = false;
 
-	from_stat = false;
-	from_open = false;
-	to_open = false;
-	from_size_local = 0;
+	static _Bool open_src;
+	static _Bool stat_src;
+	static _Bool open_dst;
+	static _Bool o_direct_open_dst;
+
+	stat_src = false;
+	open_src = false;
+	open_dst = false;
+	o_direct_open_dst = false;
+
+	src_size_local = 0;
 	written_size[0] = 0;
 	written_size[1] = 0;
 	next_write_size[0] = 0;
@@ -147,8 +149,8 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 	total_write_local = 0;
 	total_read_error = 0;
 	total_write_error = 0;
-	ifrom = 0;
-	ito = 0;
+	isrc = 0;
+	idst = 0;
 	ri = 0;
 	wi = 0;
 
@@ -179,31 +181,31 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 
 	if(filesystem_check == false)
 	{
-		char *tofs_tmp = cpinfo->tofs;
+		char *tmp = cpinfo->dstfs;
 
-		if(tofs_tmp != NULL)
+		if(tmp != NULL)
 		{
 			if
 			(
-				((tofs_tmp[0] == 'e') && (tofs_tmp[1] == 'x') && (tofs_tmp[2] == 't') && (tofs_tmp[3] == '4'))
+				((tmp[0] == 'e') && (tmp[1] == 'x') && (tmp[2] == 't') && (tmp[3] == '4'))
 				||
-				((tofs_tmp[0] == 'b') && (tofs_tmp[1] == 't') && (tofs_tmp[2] == 'r') && (tofs_tmp[2] == 'f') && (tofs_tmp[2] == 's'))
+				((tmp[0] == 'b') && (tmp[1] == 't') && (tmp[2] == 'r') && (tmp[2] == 'f') && (tmp[2] == 's'))
 				||
-				((tofs_tmp[0] == 'o') && (tofs_tmp[1] == 'c') && (tofs_tmp[2] == 'f') && (tofs_tmp[2] == 's') && (tofs_tmp[2] == '2'))
+				((tmp[0] == 'o') && (tmp[1] == 'c') && (tmp[2] == 'f') && (tmp[2] == 's') && (tmp[2] == '2'))
 			)
 			{
 				fallocate_support = true;
 			}
-			else if((tofs_tmp[0] == 'x') && (tofs_tmp[1] == 'f') && (tofs_tmp[2] == 's'))
+			else if((tmp[0] == 'x') && (tmp[1] == 'f') && (tmp[2] == 's'))
 			{
 				fallocate_support = true;
 				o_direct_write_flag = true;
 			}
 			else if
 			(
-				((tofs_tmp[0] == 'n') && (tofs_tmp[1] == 't') && (tofs_tmp[2] == 'f') && (tofs_tmp[3] == 's'))
+				((tmp[0] == 'n') && (tmp[1] == 't') && (tmp[2] == 'f') && (tmp[3] == 's'))
 				||
-				((tofs_tmp[0] == 'f') && (tofs_tmp[1] == 'u') && (tofs_tmp[2] == 's') && (tofs_tmp[3] == 'e') && (tofs_tmp[4] == 'b') && (tofs_tmp[5] == 'l') && (tofs_tmp[6] == 'k'))
+				((tmp[0] == 'f') && (tmp[1] == 'u') && (tmp[2] == 's') && (tmp[3] == 'e') && (tmp[4] == 'b') && (tmp[5] == 'l') && (tmp[6] == 'k'))
 			)
 			{
 				if(verify == true)
@@ -218,27 +220,27 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 		filesystem_check = true;
 	}
 
-	cpinfo->from_size = 0;
-	cpinfo->to_size = 0;
+	cpinfo->src_size = 0;
+	cpinfo->dst_size = 0;
 
 	/* signalハンドラ用 */
-	write_now = cpinfo->to;
+	write_now = cpinfo->dst;
 
 	errno = 0;
-	if((ifrom = open(cpinfo->from, O_RDONLY | O_NOATIME | O_NOFOLLOW)) == -1)
+	if((isrc = open(cpinfo->src, O_RDONLY | O_NOATIME | O_NOFOLLOW)) == -1)
 	{
 		switch(errno)
 		{
 		case EPERM:
 			errno = 0;
 
-			if((ifrom = open(cpinfo->from, O_RDONLY | O_NOFOLLOW)) == -1)
+			if((isrc = open(cpinfo->src, O_RDONLY | O_NOFOLLOW)) == -1)
 			{
 				print_error("open", __FILE__, __LINE__, cpdd);
 			}
 			else
 			{
-				from_open = true;
+				open_src = true;
 			}
 			break;
 
@@ -249,53 +251,50 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 	}
 	else
 	{
-		from_open = true;
+		open_src = true;
 	}
 
-	if(from_open == true)
+	static struct stat stat_buf;
+
+	if(open_src == true)
 	{
 		errno = 0;
-		if(fstat(ifrom, &stat_buf) == -1)
+		if(fstat(isrc, &stat_buf) == -1)
 		{
 			print_error("fstat", __FILE__, __LINE__, cpdd);
 		}
 		else
 		{
-			from_stat = true;
-			from_size_local = stat_buf.st_size;
-			cpdd->total_source += from_size_local;
-
-			if(from_size_local < USE_O_DIRECT_SIZE)
-			{
-				o_direct_write_flag = false;
-			}
+			stat_src = true;
+			src_size_local = stat_buf.st_size;
+			cpdd->total_source += src_size_local;
 		}
 
 		if((cpinfo->file_test == false) || (oparg->WRITE_MODE == OVERWRITE))
 		{
-			TO_OPEN
+			OPEN_CHECK_DST
 		}
-		else if(from_stat == true)
+		else if(stat_src == true)
 		{
-			struct stat stat_to;
+			struct stat stat_dst;
 
 			errno = 0;
-			if(stat(cpinfo->to, &stat_to) == -1)
+			if(stat(cpinfo->dst, &stat_dst) == -1)
 			{
 				print_error("stat", __FILE__, __LINE__, cpdd);
 
 				if(errno == ENOENT)
 				{
-					TO_OPEN
+					OPEN_CHECK_DST
 				}
 			}
 			else
 			{
 				if(oparg->WRITE_MODE == SIZE_OR_TIME)
 				{
-					if((stat_buf.st_size != stat_to.st_size) || (stat_buf.st_mtime != stat_to.st_mtime))
+					if((stat_buf.st_size != stat_dst.st_size) || (stat_buf.st_mtime != stat_dst.st_mtime))
 					{
-						TO_OPEN
+						OPEN_CHECK_DST
 					}
 					else
 					{
@@ -304,9 +303,9 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 				}
 				else
 				{
-					if((stat_buf.st_mtime > stat_to.st_mtime))
+					if((stat_buf.st_mtime > stat_dst.st_mtime))
 					{
-						TO_OPEN
+						OPEN_CHECK_DST
 					}
 					else
 					{
@@ -318,7 +317,7 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 		else
 		{
 			print_error("NODATA", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, "%s をコピーできません\n", cpinfo->from);
+			fprintf(stderr, "%s をコピーできません\n", cpinfo->src);
 		}
 	}
 
@@ -329,17 +328,17 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 	 * ext4だと4秒弱で終わるフォルダのコピーが、
 	 * ntfsだと12秒はかかる（何もしないと6秒弱、pwriteだと8秒ほど、ftruncateは何もしない場合とほぼ同じ）。
 	*/
-	if((from_size_local > 0) && (to_open == true) && (fallocate_support == true))
+	if((src_size_local > 0) && (open_dst == true) && (fallocate_support == true))
 	{
 		/* Ubuntu 11.04だとfallocateの第二引数は FALLOC_FL_KEEP_SIZE と FALLOC_FL_PUNCH_HOLE の二つ。linux/falloc.h のincludeが必要。 */
-		if(fallocate(ito, FALLOC_FL_KEEP_SIZE, 0, from_size_local) == -1)
+		if(fallocate(idst, FALLOC_FL_KEEP_SIZE, 0, src_size_local) == -1)
 		{
 			print_error("fallocate", __FILE__, __LINE__, cpdd);
 		}
 /*
 		static int itmp = -1;
 
-		if((itmp = posix_fallocate(ito, 0, from_size_local)) != 0)
+		if((itmp = posix_fallocate(idst, 0, src_size_local)) != 0)
 		{
 			errno = itmp;
 			print_error("posix_fallocate", __FILE__, __LINE__, cpdd);
@@ -348,7 +347,7 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 	}
 
 	/* コピー開始 */
-	if((from_size_local > 0) && (to_open == true))
+	if((src_size_local > 0) && (open_dst == true))
 	{
 		static md5_state_t state;
 		static md5_byte_t digest[16];
@@ -364,14 +363,14 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 
 		if(oparg->V == VERBOS)
 		{
-			printf("%s -> %s\n", cpinfo->from, cpinfo->to);
+			printf("%s -> %s\n", cpinfo->src, cpinfo->dst);
 			fflush(stdout);
 		}
 
 		/* 1048576 == 1024 * 1024 == 1MB */
-		if(1048576 > from_size_local)
+		if(1048576 > src_size_local)
 		{
-			if(o_direct_write_open == false)
+			if(o_direct_open_dst == false)
 			{
 				mw_small(cpinfo, cpdd, &state, digest, &thread_argument, &t_verify);
 			}
@@ -382,7 +381,7 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 		}
 		else if(cpinfo->copy_mode == DIFFERENT)
 		{
-			if(o_direct_write_open == false)
+			if(o_direct_open_dst == false)
 			{
 				mw_thread(oparg, cpinfo, cpdd, &state, digest, &thread_argument, &t_verify);
 			}
@@ -393,7 +392,7 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 		}
 		else
 		{
-			if(o_direct_write_open == false)
+			if(o_direct_open_dst == false)
 			{
 				mw_big(cpinfo, cpdd, &state, digest, &thread_argument, &t_verify);
 			}
@@ -403,25 +402,25 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 			}
 		}
 
-		if(o_direct_write_open == true)
+		if(o_direct_open_dst == true)
 		{
-			if(ftruncate(ito, from_size_local) == -1)
+			if(ftruncate(idst, src_size_local) == -1)
 			{
 				print_error("ftruncate", __FILE__, __LINE__, cpdd);
 			}
 		}
 	}
-	else if((from_size_local == 0) && (to_open == true))
+	else if((src_size_local == 0) && (open_dst == true))
 	{
-		if(ftruncate(ito, 0) == -1)
+		if(ftruncate(idst, 0) == -1)
 		{
 			print_error("ftruncate", __FILE__, __LINE__, cpdd);
 		}
 	}
 
-	if((from_stat == true) && (to_open == true))
+	if((stat_src == true) && (open_dst == true))
 	{
-		ch_time_and_mod(&ito, &stat_buf, cpinfo, cpdd);
+		ch_time_and_mod(&idst, &stat_buf, cpinfo, cpdd);
 	}
 
 /*
@@ -429,24 +428,24 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 
 	if((oparg->CHECK != NOT) && (fallocate_support == true))
 	{
-		if(fdatasync(ito) == -1)
+		if(fdatasync(idst) == -1)
 		{
 			print_error("fdatasync", __FILE__, __LINE__, cpdd);
 		}
 	}
 */
 
-	if(from_open == true)
+	if(open_src == true)
 	{
-		if(close(ifrom) == -1)
+		if(close(isrc) == -1)
 		{
 			print_error("close", __FILE__, __LINE__, cpdd);
 		}
 	}
 
-	if(to_open == true)
+	if(open_dst == true)
 	{
-		if(close(ito) == -1)
+		if(close(idst) == -1)
 		{
 			print_error("close", __FILE__, __LINE__, cpdd);
 		}
@@ -454,13 +453,13 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 
 	if(total_read_local > 0)
 	{
-		cpinfo->from_size = from_size_local;
+		cpinfo->src_size = src_size_local;
 		cpdd->total_read += total_read_local;
 	}
 
 	if(total_write_local > 0)
 	{
-		cpinfo->to_size = total_write_local;
+		cpinfo->dst_size = total_write_local;
 		cpdd->total_write += total_write_local;
 	}
 
@@ -476,7 +475,7 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 
 	write_now = NULL;
 
-	if((from_open == true) && (to_open == true) && (from_size_local <= total_write_local))
+	if((open_src == true) && (open_dst == true) && (src_size_local <= total_write_local))
 	{
 		cpinfo->write = true;
 	}
@@ -500,26 +499,26 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 		case V_FIVE:
 			if(cpinfo->verify_md5 == NULL)
 			{
-				if(from_size_local > 0)
+				if(src_size_local > 0)
 				{
 					fprintf(stderr, "ベリファイをスキップします\n");
-					fprintf(stderr, "to : %s\n", cpinfo->to);
+					fprintf(stderr, "dst : %s\n", cpinfo->dst);
 				}
-				else if((from_size_local < 0))
+				else if((src_size_local < 0))
 				{
 					fprintf(stderr, "コピー元のファイサイズが不正です\n");
 					fprintf(stderr, "ベリファイをスキップします\n");
-					fprintf(stderr, "to : %s\n", cpinfo->to);
+					fprintf(stderr, "dst : %s\n", cpinfo->dst);
 				}
 			}
-			else if((to_open == true) && (from_size_local > 0))
+			else if((open_dst == true) && (src_size_local > 0))
 			{
 				verify_hash(oparg, sdir, cpinfo, cpdd);
 			}
 			else
 			{
 				fprintf(stderr, "ベリファイをスキップします\n");
-				fprintf(stderr, "to : %s\n", cpinfo->to);
+				fprintf(stderr, "dst : %s\n", cpinfo->dst);
 			}
 			break;
 
@@ -541,7 +540,7 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 inline static void mw_small(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify)
 {
 	errno = 0;
-	buf[0] = mmap(NULL, from_size_local, PROT_READ, MAP_PRIVATE, ifrom, 0);
+	buf[0] = mmap(NULL, src_size_local, PROT_READ, MAP_PRIVATE, isrc, 0);
 
 	if(buf[0] == MAP_FAILED)
 	{
@@ -549,10 +548,10 @@ inline static void mw_small(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_
 	}
 	else
 	{
-		total_read_local = from_size_local;
+		total_read_local = src_size_local;
 
 		errno = 0;
-		if(madvise(buf[0], from_size_local, MADV_SEQUENTIAL) == -1)
+		if(madvise(buf[0], src_size_local, MADV_SEQUENTIAL) == -1)
 		{
 			print_error("madvise", __FILE__, __LINE__, cpdd);
 		}
@@ -561,18 +560,18 @@ inline static void mw_small(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_
 		{
 			thread_argument->state = state;
 			thread_argument->buffer = buf[0];
-			thread_argument->len = from_size_local;
+			thread_argument->len = src_size_local;
 
 			pthread_create(t_verify, NULL, do_md5_append, (void *)thread_argument);
 		}
 
 		char *tmp = buf[0];
-		const char * const endp = tmp + from_size_local;
+		const char * const endp = tmp + src_size_local;
 
 		while(tmp < endp)
 		{
 			errno = 0;
-			if((written_size[0] = write(ito, tmp, endp - tmp)) == -1)
+			if((written_size[0] = write(idst, tmp, endp - tmp)) == -1)
 			{
 				print_error("write", __FILE__, __LINE__, cpdd);
 				break;
@@ -589,7 +588,7 @@ inline static void mw_small(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_
 		}
 
 		errno = 0;
-		if(munmap(buf[0], from_size_local) != 0)
+		if(munmap(buf[0], src_size_local) != 0)
 		{
 			print_error("munmap", __FILE__, __LINE__, cpdd);
 		}
@@ -605,7 +604,7 @@ inline static void mw_small_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *stat
 
 	for(;;)
 	{
-		off_t read_remainder = from_size_local - total_read_local;
+		off_t read_remainder = src_size_local - total_read_local;
 
 		if(read_remainder <= 0)
 		{
@@ -631,7 +630,7 @@ inline static void mw_small_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *stat
 		}
 
 		errno = 0;
-		buf[0] = mmap(NULL, read_size, PROT_READ, MAP_PRIVATE, ifrom, total_read_local);
+		buf[0] = mmap(NULL, read_size, PROT_READ, MAP_PRIVATE, isrc, total_read_local);
 
 		if(buf[0] == MAP_FAILED)
 		{
@@ -660,7 +659,7 @@ inline static void mw_small_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *stat
 			for(;;)
 			{
 				errno = 0;
-				if((written_size[0] = pwrite(ito, buf[0], write_size, total_write_local)) == -1)
+				if((written_size[0] = pwrite(idst, buf[0], write_size, total_write_local)) == -1)
 				{
 					print_error("write", __FILE__, __LINE__, cpdd);
 					break;
@@ -670,7 +669,7 @@ inline static void mw_small_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *stat
 				{
 					total_write_local += written_size[0];
 
-					if(lseek(ito, write_size, SEEK_CUR) == -1)
+					if(lseek(idst, write_size, SEEK_CUR) == -1)
 					{
 						print_error("lseek", __FILE__, __LINE__, cpdd);
 					}
@@ -705,7 +704,7 @@ inline static void mw_big(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_by
 {
 	for(;;)
 	{
-		off_t read_size = from_size_local - total_read_local;
+		off_t read_size = src_size_local - total_read_local;
 
 		if(read_size >= buffer_size)
 		{
@@ -722,7 +721,7 @@ inline static void mw_big(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_by
 		}
 
 		errno = 0;
-		buf[0] = mmap(NULL, read_size, PROT_READ, MAP_PRIVATE, ifrom, total_read_local);
+		buf[0] = mmap(NULL, read_size, PROT_READ, MAP_PRIVATE, isrc, total_read_local);
 
 		if(buf[0] == MAP_FAILED)
 		{
@@ -754,7 +753,7 @@ inline static void mw_big(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_by
 			while(tmp < endp)
 			{
 				errno = 0;
-				if((written_size[0] = write(ito, tmp, endp - tmp)) == -1)
+				if((written_size[0] = write(idst, tmp, endp - tmp)) == -1)
 				{
 					print_error("write", __FILE__, __LINE__, cpdd);
 
@@ -782,7 +781,7 @@ inline static void mw_big(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_by
 			}
 		}
 
-		if(total_read_local >= from_size_local)
+		if(total_read_local >= src_size_local)
 		{
 			break;
 		}
@@ -804,7 +803,7 @@ inline static void mw_big_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state,
 
 	for(;;)
 	{
-		off_t read_remainder = from_size_local - total_read_local;
+		off_t read_remainder = src_size_local - total_read_local;
 
 		if(read_remainder <= 0)
 		{
@@ -840,7 +839,7 @@ inline static void mw_big_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state,
 		}
 
 		errno = 0;
-		buf[0] = mmap(NULL, read_size, PROT_READ, MAP_PRIVATE, ifrom, total_read_local);
+		buf[0] = mmap(NULL, read_size, PROT_READ, MAP_PRIVATE, isrc, total_read_local);
 
 		if(buf[0] == MAP_FAILED)
 		{
@@ -869,7 +868,7 @@ inline static void mw_big_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state,
 			for(;;)
 			{
 				errno = 0;
-				if((written_size[0] = pwrite(ito, buf[0], write_size, total_write_local)) == -1)
+				if((written_size[0] = pwrite(idst, buf[0], write_size, total_write_local)) == -1)
 				{
 					print_error("write", __FILE__, __LINE__, cpdd);
 					break;
@@ -879,7 +878,7 @@ inline static void mw_big_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state,
 				{
 					total_write_local += written_size[0];
 
-					if(lseek(ito, write_size, SEEK_CUR) == -1)
+					if(lseek(idst, write_size, SEEK_CUR) == -1)
 					{
 						print_error("lseek", __FILE__, __LINE__, cpdd);
 					}
@@ -927,7 +926,7 @@ cpdd->thread_mode_count++;\
 		i = (int *)b_size_list->data;\
 		high = *i;\
 \
-		if(high > from_size_local)\
+		if(high > src_size_local)\
 		{\
 			buffer_size_thread = low;\
 			break;\
@@ -985,7 +984,7 @@ inline static void mw_thread(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, md5
 			while(tmp < endp)
 			{
 				errno = 0;
-				if((written_size[wi] = write(ito, tmp, endp - tmp)) == -1)
+				if((written_size[wi] = write(idst, tmp, endp - tmp)) == -1)
 				{
 					print_error("write", __FILE__, __LINE__, cpdd);
 					total_write_error++;
@@ -1018,7 +1017,7 @@ inline static void mw_thread(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, md5
 
 		pthread_join(t_read, NULL);
 
-		if((from_size_local <= total_write_local) || (written_size[wi] <= 0))
+		if((src_size_local <= total_write_local) || (written_size[wi] <= 0))
 		{
 			break;
 		}
@@ -1075,7 +1074,7 @@ inline static void mw_thread_direct(const OPArg *oparg, CPInfo *cpinfo, CPDD *cp
 			while(tmp < endp)
 			{
 				errno = 0;
-				written_size[wi] = pwrite(ito, tmp, endp - tmp, total_write_local);
+				written_size[wi] = pwrite(idst, tmp, endp - tmp, total_write_local);
 
 				if(written_size[wi] == -1)
 				{
@@ -1088,7 +1087,7 @@ inline static void mw_thread_direct(const OPArg *oparg, CPInfo *cpinfo, CPDD *cp
 					tmp += written_size[wi];
 					total_write_local += written_size[wi];
 
-					if(lseek(ito, total_write_local + written_size[wi], SEEK_SET) == -1)
+					if(lseek(idst, total_write_local + written_size[wi], SEEK_SET) == -1)
 					{
 						print_error("write", __FILE__, __LINE__, cpdd);
 						total_write_error++;
@@ -1119,7 +1118,7 @@ inline static void mw_thread_direct(const OPArg *oparg, CPInfo *cpinfo, CPDD *cp
 
 		pthread_join(t_read, NULL);
 
-		if((from_size_local <= total_write_local) || (written_size[wi] <= 0))
+		if((src_size_local <= total_write_local) || (written_size[wi] <= 0))
 		{
 			break;
 		}
@@ -1139,13 +1138,13 @@ static void * read_thread_func(void *unknown)
 	int i = ri;
 	unknown++;	/* コンパイル時のwarningを出さないようにするため */
 
-	if(from_size_local <= total_read_local)
+	if(src_size_local <= total_read_local)
 	{
 		next_write_size[i] = 0;
 		return NULL;
 	}
 
-	off_t read_size = from_size_local - total_read_local;
+	off_t read_size = src_size_local - total_read_local;
 
 	if(read_size >= buffer_size_thread)
 	{
@@ -1162,7 +1161,7 @@ static void * read_thread_func(void *unknown)
 	}
 
 	errno = 0;
-	buf[i] = mmap(NULL, read_size, PROT_READ, MAP_PRIVATE, ifrom, total_read_local);
+	buf[i] = mmap(NULL, read_size, PROT_READ, MAP_PRIVATE, isrc, total_read_local);
 
 	if(buf[i] == MAP_FAILED)
 	{
