@@ -21,7 +21,7 @@
 
 /* 関数プロトタイプ */
 static inline void do_compare_verify_two(const OPArg *oparg, const VList *file_list, const SDir *sdir, CPDD *cpdd) __attribute__((always_inline));
-static inline void delete_from(const OPArg *oparg, const VList *file_list, CPDD *cpdd) __attribute__((always_inline));
+static inline void delete_src(const OPArg *oparg, const VList *file_list, CPDD *cpdd) __attribute__((always_inline));
 
 /*******************************************************************************
 *******************************************************************************/
@@ -101,7 +101,7 @@ int main(int argc, char **argv)
 			puts("コピー元の削除を開始します...");
 			fflush(stdout);
 
-			delete_from(oparg, file_list, cpdd);
+			delete_src(oparg, file_list, cpdd);
 
 			puts("コピー元の削除を完了しました...");
 			fflush(stdout);
@@ -146,12 +146,12 @@ int main(int argc, char **argv)
 #define FILE_REMOVE \
 {\
 	errno = 0;\
-	if(unlink(cpinfo->from) == -1)\
+	if(unlink(cpinfo->src) == -1)\
 	{\
 		if(errno != ENOENT)\
 		{\
 			print_error("unlink", __FILE__, __LINE__, cpdd);\
-			fprintf(stderr, "%s の削除に失敗しました\n", cpinfo->from);\
+			fprintf(stderr, "%s の削除に失敗しました\n", cpinfo->src);\
 		}\
 	}\
 }
@@ -174,8 +174,8 @@ int main(int argc, char **argv)
 	else if((cpinfo->write == false) && (cpinfo->skip == false))\
 	{\
 		fprintf(stderr, "ファイルの書き込みに失敗しているため、コンペアをスキップします\n");\
-		fprintf(stderr, "from : %s\n", cpinfo->from);\
-		fprintf(stderr, "to   : %s\n", cpinfo->to);\
+		fprintf(stderr, "src : %s\n", cpinfo->src);\
+		fprintf(stderr, "dst : %s\n", cpinfo->dst);\
 	}\
 }
 
@@ -193,7 +193,7 @@ static inline void do_compare_verify_two(const OPArg *oparg, const VList *file_l
 	{
 		CPInfo *cpinfo = (CPInfo *)tmp->data;
 
-		if(cpinfo->from_type == REGULAR)
+		if(cpinfo->src_type == REGULAR)
 		{
 			switch(oparg->CHECK)
 			{
@@ -208,16 +208,16 @@ static inline void do_compare_verify_two(const OPArg *oparg, const VList *file_l
 			case V_FIVE:
 				if(cpinfo->verify_md5 == NULL)
 				{
-					if(cpinfo->from_size > 0)
+					if(cpinfo->src_size > 0)
 					{
 						fprintf(stderr, "ベリファイをスキップします\n");
-						fprintf(stderr, "to : %s\n", cpinfo->to);
+						fprintf(stderr, "dst : %s\n", cpinfo->dst);
 					}
-					else if(cpinfo->from_size < 0)
+					else if(cpinfo->src_size < 0)
 					{
 						fprintf(stderr, "コピー元のファイサイズが不正です\n");
 						fprintf(stderr, "ベリファイをスキップします\n");
-						fprintf(stderr, "to : %s\n", cpinfo->to);
+						fprintf(stderr, "dst : %s\n", cpinfo->dst);
 					}
 				}
 				else
@@ -253,7 +253,7 @@ static inline void do_compare_verify_two(const OPArg *oparg, const VList *file_l
 
 /*******************************************************************************
 *******************************************************************************/
-static inline void delete_from(const OPArg *oparg, const VList *file_list, CPDD *cpdd)
+static inline void delete_src(const OPArg *oparg, const VList *file_list, CPDD *cpdd)
 {
 	/*
 	* キャストしないと警告が出る
@@ -266,23 +266,23 @@ static inline void delete_from(const OPArg *oparg, const VList *file_list, CPDD
 	{
 		CPInfo *cpinfo = (CPInfo *)tmp->data;
 
-		switch(cpinfo->from_type)
+		switch(cpinfo->src_type)
 		{
 		case REGULAR:
 			if(oparg->CHECK == NOT)
 			{
-				if((cpinfo->write == true) && (cpinfo->from_size == cpinfo->to_size))
+				if((cpinfo->write == true) && (cpinfo->src_size == cpinfo->dst_size))
 				{
 					FILE_REMOVE
 				}
 			}
 			else
 			{
-				if((cpinfo->hash_check == true) && (cpinfo->write == true) && (cpinfo->from_size == cpinfo->to_size))
+				if((cpinfo->hash_check == true) && (cpinfo->write == true) && (cpinfo->src_size == cpinfo->dst_size))
 				{
 					FILE_REMOVE
 				}
-				else if((cpinfo->write == true) && (cpinfo->from_size == 0) && (cpinfo->to_size == 0))
+				else if((cpinfo->write == true) && (cpinfo->src_size == 0) && (cpinfo->dst_size == 0))
 				{
 					FILE_REMOVE
 				}
@@ -298,12 +298,12 @@ static inline void delete_from(const OPArg *oparg, const VList *file_list, CPDD
 
 		case DIRECTORY:
 			errno = 0;
-			if(rmdir(cpinfo->from) == -1)
+			if(rmdir(cpinfo->src) == -1)
 			{
 				if((errno != ENOTEMPTY) && (errno != ENOENT))
 				{
 					print_error("remove", __FILE__, __LINE__, cpdd);
-					fprintf(stderr, "%s の削除に失敗しました\n", cpinfo->from);
+					fprintf(stderr, "%s の削除に失敗しました\n", cpinfo->src);
 				}
 			}
 			break;
