@@ -18,18 +18,18 @@ typedef enum copy_file_type
 
 typedef struct copy_infomation
 {
-	char *from;
-	char *to;
-	char *tofs;
-	enum copy_file_type from_type;
+	char *src;
+	char *dst;
+	char *dstfs;
+	enum copy_file_type src_type;
 	enum copy_mode_flag copy_mode;
 	_Bool write;
 	_Bool skip;
 	_Bool hash_check;
 	_Bool file_test;
 	char *verify_md5;
-	off_t from_size;
-	off_t to_size;
+	off_t src_size;
+	off_t dst_size;
 } CPInfo;
 
 #endif
