@@ -27,7 +27,7 @@ static md5_state_t state;
 static md5_byte_t digest[16];
 static int read_size[BUF_NUM];
 static off_t total;
-static off_t static_to_size;
+static off_t static_dst_size;
 static int r_number;
 static int a_number;
 static _Bool lseek_err;
@@ -40,12 +40,12 @@ static _Bool read_finish;
 	cpinfo->write = false;\
 \
 	errno = 0;\
-	if(unlink(cpinfo->to) == -1)\
+	if(unlink(cpinfo->dst) == -1)\
 	{\
 		if(errno != ENOENT)\
 		{\
 			print_error("unlink", __FILE__, __LINE__, cpdd);\
-			fprintf(stderr, "%s の削除に失敗しました\n", cpinfo->to);\
+			fprintf(stderr, "%s の削除に失敗しました\n", cpinfo->dst);\
 		}\
 	}
 
@@ -64,7 +64,7 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 	read_size[0] = 0;
 	read_size[1] = 0;
 	total = 0;
-	static_to_size = cpinfo->to_size;
+	static_dst_size = cpinfo->dst_size;
 	lseek_err = false;
 	read_err = false;
 	read_finish = false;
@@ -77,12 +77,12 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 	}
 
 	errno = 0;
-	if((fd = open(cpinfo->to, O_NOATIME | O_NOFOLLOW | O_DIRECT | O_RDONLY)) == -1)
+	if((fd = open(cpinfo->dst, O_NOATIME | O_NOFOLLOW | O_DIRECT | O_RDONLY)) == -1)
 	{
 		switch(errno)
 		{
 		case EPERM:
-			if((fd = open(cpinfo->to, O_NOFOLLOW | O_DIRECT | O_RDONLY)) == -1)
+			if((fd = open(cpinfo->dst, O_NOFOLLOW | O_DIRECT | O_RDONLY)) == -1)
 			{
 				print_error("open", __FILE__, __LINE__, cpdd);
 			}
@@ -109,7 +109,7 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 			if((posix_memalign((void **)&buf[0], psize, buffer_size_local) != 0) || (posix_memalign((void **)&buf[1], psize, buffer_size_local) != 0))
 			{
 				fprintf(stderr, "ベリファイに失敗しました\n");
-				fprintf(stderr, "%s\n", cpinfo->to);
+				fprintf(stderr, "%s\n", cpinfo->dst);
 				print_error("posix_memalign", __FILE__, __LINE__, cpdd);
 				write_log_hash_check(cpinfo, cpinfo->verify_md5, "NULL", sdir, cpdd, false);
 			}
@@ -168,8 +168,8 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 
 				if(oparg->V == VERBOS)
 				{
-					printf("%s : %s\n", cpinfo->verify_md5, cpinfo->from);
-					printf("%s : %s\n", hex_output, cpinfo->to);
+					printf("%s : %s\n", cpinfo->verify_md5, cpinfo->src);
+					printf("%s : %s\n", hex_output, cpinfo->dst);
 					fflush(stdout);
 				}
 
@@ -178,14 +178,14 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 					write_log_hash_check(cpinfo, cpinfo->verify_md5, hex_output, sdir, cpdd, true);
 				}
 			}
-			else if(cpinfo->from_size > total)
+			else if(cpinfo->src_size > total)
 			{
-				fprintf(stderr, "ファイルの読み込みに失敗しました、%sを削除します\n", cpinfo->to);
+				fprintf(stderr, "ファイルの読み込みに失敗しました、%sを削除します\n", cpinfo->dst);
 				UNLINK_MISS_FILE
 			}
 			else
 			{
-				fprintf(stderr, "ハッシュ値が一致しませんでした、%sを削除します\n", cpinfo->to);
+				fprintf(stderr, "ハッシュ値が一致しませんでした、%sを削除します\n", cpinfo->dst);
 				UNLINK_MISS_FILE
 			}
 			break;
@@ -202,7 +202,7 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 	else
 	{
 		fprintf(stderr, "ベリファイに失敗しました\n");
-		fprintf(stderr, "%sをオープン出来ません\n", cpinfo->to);
+		fprintf(stderr, "%sをオープン出来ません\n", cpinfo->dst);
 		print_error("NODATA", __FILE__, __LINE__, cpdd);
 		write_log_hash_check(cpinfo, cpinfo->verify_md5, "NULL", sdir, cpdd, false);
 		cpinfo->write = false;
